{ config, lib, pkgs, ... }:

{
  imports = [
    ./hardware.nix
  ];

  # Configure Nix
  nix.package = pkgs.lix;
  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];
  };
  nix.settings.trusted-users=[ "remotebuild" ];

  # Networking
  networking.hostName = "mow0m";
  networking.networkmanager.enable = true;

  # Set your time zone.
  time.timeZone = "Europe/Amsterdam";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "de";
  };

  users.users.master = {
    isNormalUser = true;
    extraGroups = [ "wheel" ];
    packages = with pkgs; [
      tree
    ];
    openssh.authorizedKeys.keys = [
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIF+qnaWHrGk+DHz5I3L8wK5MPVzjck9LTuctnzK55WJs kb@LoyAdjo"
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAICc3ShcoW5cPw1sbwiKI8ldMNtPi5xb6FPd/oH4AoSJW kb@Ohybke"
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIGL0MCmqvwph9Py81MtAjpJHtw5ecyE3s3q/SQW+D7HJ wdlbrmft"
    ];
  };

  users.users.remotebuild = {
    isNormalUser = true;
    createHome = true;
    openssh.authorizedKeys.keys = [
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIJW6aXcRu9+eYHi6taG8uWiG3XMJ429sax8EMyLHa31C kissen@Lolquak"
    ];
  };



  # programs.firefox.enable = true;

  # System Packages: (search via $ nix search wget)
  environment.systemPackages = with pkgs; [
    vim
    tree
    wget
    git
    fastfetch
    ripgrep
  ];

  # SSH and Mosh
  services.openssh = {
    enable = true;
    settings.PasswordAuthentication = false;
    settings.KbdInteractiveAuthentication = false;
    ports = [ 9553 ];
    openFirewall = true;
  };
  programs.mosh.enable = true;

  services.asterisk-phony.enable = true;

  # Enable NAS Suite
  suites.nas.enable = true;
  suites.nas.debug = true;
  suites.nas.domain = "mow0m";
  suites.nas.media.enable = true;
  suites.nas.media.folder = "/laowu/media";
  suites.nas.media.servers.enable = true;

  # Firewall
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];

  system.stateVersion = "24.11"; # NEVER CHANGE THIS!!! 
}

